==> codelite_6.1.1+dfsg.orig.tar.gz: codelite-6.1.1/LiteEditor/FilesModifiedDlg.cpp <==
//////////////////////////////////////////////////////////////////////////////
//////////////////////////////////////////////////////////////////////////////
//
// copyright            : (C) 2014 The CodeLite Team
// file name            : FilesModifiedDlg.cpp
//
// -------------------------------------------------------------------------
// A
//              _____           _      _     _ _
//             /  __ \         | |    | |   (_) |
//             | /  \/ ___   __| | ___| |    _| |_ ___
//             | |    / _ \ / _  |/ _ \ |   | | __/ _ )
//             | \__/\ (_) | (_| |  __/ |___| | ||  __/
//              \____/\___/ \__,_|\___\_____/_|\__\___|
//
//                                                  F i l e
//
//    This program is free software; you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation; either version 2 of the License, or
//    (at your option) any later version.
//
//////////////////////////////////////////////////////////////////////////////
//////////////////////////////////////////////////////////////////////////////

#include "FilesModifiedDlg.h"

FilesModifiedDlg::FilesModifiedDlg(wxWindow* parent)
    : FilesModifiedDlgBase(parent)
{
}

FilesModifiedDlg::~FilesModifiedDlg()
{
}

void FilesModifiedDlg::OnChoose(wxCommandEvent& event)
{
    event.StopPropagation();
    CallAfter( &FilesModifiedDlg::EndModal, ID_BUTTON_CHOOSE );
}

void FilesModifiedDlg::OnLoad(wxCommandEvent& event)
{
    event.StopPropagation();
    CallAfter( &FilesModifiedDlg::EndModal, ID_BUTTON_LOAD );
}

==> codelite_9.0+dfsg.orig.tar.gz: codelite-9.0/LiteEditor/FilesModifiedDlg.cpp <==
//////////////////////////////////////////////////////////////////////////////
//////////////////////////////////////////////////////////////////////////////
//
// copyright            : (C) 2014 The CodeLite Team
// file name            : FilesModifiedDlg.cpp
//
// -------------------------------------------------------------------------
// A
//              _____           _      _     _ _
//             /  __ \         | |    | |   (_) |
//             | /  \/ ___   __| | ___| |    _| |_ ___
//             | |    / _ \ / _  |/ _ \ |   | | __/ _ )
//             | \__/\ (_) | (_| |  __/ |___| | ||  __/
//              \____/\___/ \__,_|\___\_____/_|\__\___|
//
//                                                  F i l e
//
//    This program is free software; you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation; either version 2 of the License, or
//    (at your option) any later version.
//
//////////////////////////////////////////////////////////////////////////////
//////////////////////////////////////////////////////////////////////////////

#include "FilesModifiedDlg.h"

FilesModifiedDlg::FilesModifiedDlg(wxWindow* parent)
    : FilesModifiedDlgBase(parent)
{
    GetSizer()->Fit(this);
    CentreOnParent();
}

FilesModifiedDlg::~FilesModifiedDlg() {}

void FilesModifiedDlg::OnChoose(wxCommandEvent& event)
{
    event.StopPropagation();
    CallAfter(&FilesModifiedDlg::EndModal, ID_BUTTON_CHOOSE);
}

void FilesModifiedDlg::OnLoad(wxCommandEvent& event)
{
    event.StopPropagation();
    CallAfter(&FilesModifiedDlg::EndModal, ID_BUTTON_LOAD);
}

void FilesModifiedDlg::OnIgnore(wxCommandEvent& event)
{
    event.StopPropagation();
    CallAfter(&FilesModifiedDlg::EndModal, ID_BUTTON_IGNORE);
}
